#
# spec file for package avidemux3
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1320 || 0%{?sle_version}
%bcond_without  build_qt5
%define         qtversion 5
%else
%bcond_with     build_qt5
%define         qtversion 4
%endif

%if 0%{?suse_version} > 1320 || 0%{?sle_version} > 120100
%bcond_without  with_vs
%endif

Name:           avidemux3
Summary:        Graphical video editing and transcoding tool
Version:        2.6.20
Release:        1.1
Url:            http://avidemux.sourceforge.net/
Source0:        avidemux_%{version}.tar.gz
Source1:        avidemux3-qt.desktop
Source2:        avidemux3-vsproxy-qt.desktop
Source3:        config.mak.diff
Patch0:         avidemux-cmake-2.8.8.patch
Patch1:         avidemux-linking.patch
Patch2:         avidemux-x264_plugins.patch
Patch3:         avidemux-x265_plugins.patch
Patch4:         avidemux-package_version.patch
Patch5:         avidemux-bootStrap.patch
Patch6:         avidemux-cmake-permissions.patch
Patch7:         avidemux-cpu_armel.patch
License:        GPL-2.0
Group:          Productivity/Multimedia/Video/Editors and Convertors

# Utilities / Libraries
BuildRequires:  cmake
BuildRequires:  gettext-tools
BuildRequires:  intltool
BuildRequires:  desktop-file-utils
BuildRequires:  pkg-config
BuildRequires:  fdupes
BuildRequires:  dos2unix
BuildRequires:  yasm
%if %{with with_vs}
BuildRequires:  pkgconfig(vapoursynth)
BuildRequires:  libvapoursynth-script
%endif
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(sqlite3)

# Sound out
BuildRequires:  arts-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(esound)

# Video out
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(libva)

# Audio Codecs
BuildRequires:  libfaac-devel
BuildRequires:  libfaad-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libaften-devel
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(fdk-aac)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(liba52)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(libdca)
BuildRequires:  pkgconfig(opencore-amrnb)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(dcaenc)

# Video Codecs
BuildRequires:  libxvidcore-devel
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(x265)

%if %{with build_qt5}
# QT5-GUI
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Widgets)
%else
# QT4-GUI
BuildRequires:  pkgconfig(QtCore) >= 4.7
%endif

# Main package requires at least one frontend (cli or qt4)
Requires:       avidemux3-frontend = %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

%package cli
Summary:        CLI for avidemux
Group:          Productivity/Multimedia/Video/Editors and Convertors
Provides:       avidemux3-frontend = %{version}-%{release}
Requires:       avidemux3 = %{version}-%{release}

%description cli
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

This package provides a command-line interface to editing videos with avidemux.

%package qt%{qtversion}
Summary:        Qt interface for avidemux
Group:          Productivity/Multimedia/Video/Editors and Convertors
Provides:       avidemux3-frontend = %{version}-%{release}
Requires:       avidemux3 = %{version}-%{release}
Recommends:     avidemux3-qt%{qtversion}-lang = %{version}-%{release}

%description qt%{qtversion}
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

This package contains the Qt graphical interface for avidemux.

%package qt%{qtversion}-lang
Summary:        Languages for package avidemux3-qt%{qtversion}
Group:          System/Localization
Requires:       avidemux3-qt%{qtversion} = %{version}-%{release}
BuildArch:      noarch

%description qt%{qtversion}-lang
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs. Tasks can be automated
using projects, job queue and powerful scripting capabilities.

Avidemux is available for Linux, BSD, Mac OS X and Microsoft Windows under
the GNU GPL license. The program was written from scratch by Mean, but code
from other people and projects has been used as well. Patches, translations
and even bug reports are always welcome.

This package provides translations for package avidemux3-qt%{qtversion}.


%prep
%setup -q -n avidemux_%{version}
for i in bash cmake cpp sh sql txt; do
  find . -name \*.$i -print0 | xargs -0 dos2unix -q
done
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p1
%patch5 -p0
%patch6 -p0
%patch7 -p0
cp -f %{S:3} avidemux_core/ffmpeg_package/patches/
chmod 755 bootStrap.bash
chmod 644 AUTHORS COPYING README

%build
flags+="%optflags -fno-strict-aliasing "
%if 0%{?suse_version} == 1320
%ifarch %ix86
flags+="-fno-stack-protector "
%endif
%endif
export CXXFLAGS="$flags"

options+="--with-cli "
%if %{with build_qt5}
options+="--with-qt "
%else
options+="--with-qt --enable-qt4 "
%endif
./bootStrap.bash $options

%install
cp -r install/* %{buildroot}

# Install desktop file
install -D -m644 %{S:1} %{buildroot}%{_datadir}/applications/avidemux3-qt%{qtversion}.desktop
sed -i -e 's|qtversion|%{qtversion}|g' %{buildroot}%{_datadir}/applications/avidemux3-qt%{qtversion}.desktop
%if %{with with_vs}
install -D -m644 %{S:2} %{buildroot}%{_datadir}/applications/vsproxy-qt%{qtversion}.desktop
sed -i -e 's|qtversion|%{qtversion}|g' %{buildroot}%{_datadir}/applications/vsproxy-qt%{qtversion}.desktop
%endif

# Install icon
install -D -m644 avidemux_icon.png %{buildroot}%{_datadir}/pixmaps/avidemux3.png

# Install man
install -D -m644 man/avidemux.1 %{buildroot}%{_mandir}/man1/avidemux.1

# delete devel file (only needed for build)
rm -rf %{buildroot}%{_includedir}

%fdupes %buildroot

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post cli -p /sbin/ldconfig

%postun cli -p /sbin/ldconfig

%post qt%{qtversion}
/sbin/ldconfig
%desktop_database_post

%postun qt%{qtversion}
/sbin/ldconfig
%desktop_database_postun

%files
%defattr(-,root,root)
%if %{with with_vs}
%{_bindir}/vsProxy
%endif
%{_libdir}/libADM6avcodec.so.*
%{_libdir}/libADM6avformat.so.*
%{_libdir}/libADM6avutil.so.*
%{_libdir}/libADM6postproc.so.*
%{_libdir}/libADM6swscale.so.*
%{_libdir}/libADM_audioParser6.so
%{_libdir}/libADM_core6.so
%{_libdir}/libADM_coreAudio6.so
%{_libdir}/libADM_coreAudioDevice6.so
%{_libdir}/libADM_coreAudioEncoder6.so
%{_libdir}/libADM_coreAudioFilterAPI6.so
%{_libdir}/libADM_coreDemuxer6.so
%{_libdir}/libADM_coreDemuxerMpeg6.so
%{_libdir}/libADM_coreImage6.so
%{_libdir}/libADM_coreImageLoader6.so
%{_libdir}/libADM_coreJobs.so
%{_libdir}/libADM_coreLibVA6.so
%{_libdir}/libADM_coreMuxer6.so
%{_libdir}/libADM_coreScript.so
%{_libdir}/libADM_coreSocket6.so
%{_libdir}/libADM_coreSqlLight3.so
%{_libdir}/libADM_coreSubtitle.so
%{_libdir}/libADM_coreUI6.so
%{_libdir}/libADM_coreUtils6.so
%{_libdir}/libADM_coreVDPAU6.so
%{_libdir}/libADM_coreVideoCodec6.so
%{_libdir}/libADM_coreVideoEncoder6.so
%{_libdir}/libADM_coreVideoFilter6.so
%dir %{_libdir}/ADM_plugins6
%dir %{_libdir}/ADM_plugins6/audioDecoder
%dir %{_libdir}/ADM_plugins6/audioDevices
%dir %{_libdir}/ADM_plugins6/audioEncoders
%dir %{_libdir}/ADM_plugins6/autoScripts
%dir %{_libdir}/ADM_plugins6/autoScripts/lib
%dir %{_libdir}/ADM_plugins6/demuxers
%dir %{_libdir}/ADM_plugins6/muxers
%dir %{_libdir}/ADM_plugins6/pluginSettings
%dir %{_libdir}/ADM_plugins6/pluginSettings/x264
%dir %{_libdir}/ADM_plugins6/pluginSettings/x264/3
%dir %{_libdir}/ADM_plugins6/scriptEngines
%dir %{_libdir}/ADM_plugins6/videoDecoders
%dir %{_libdir}/ADM_plugins6/videoEncoders
%dir %{_libdir}/ADM_plugins6/videoFilters
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_a52.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_dca.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_faad.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_ima_adpcm.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_lav.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_Mad.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_ms_adpcm.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_opencore_amrnb.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_opencore_amrwb.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_opus.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_ulaw.so
%{_libdir}/ADM_plugins6/audioDecoder/libADM_ad_vorbis.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_alsaDefault.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_alsaDMix.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_alsaHw.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_esd.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_jack.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_oss.so
%{_libdir}/ADM_plugins6/audioDevices/libADM_av_pulseAudioSimple.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_aften.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_dcaenc.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_faac.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_fdk_aac.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lame.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lav_aac.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lav_ac3.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_lav_mp2.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_pcm.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_twolame.so
%{_libdir}/ADM_plugins6/audioEncoders/libADM_ae_vorbis.so
%{_libdir}/ADM_plugins6/autoScripts/720p.py
%{_libdir}/ADM_plugins6/autoScripts/check24fps.py
%{_libdir}/ADM_plugins6/autoScripts/dvd.py
%{_libdir}/ADM_plugins6/autoScripts/lib/ADM_image.py
%{_libdir}/ADM_plugins6/autoScripts/lib/ADM_imageInfo.py
%{_libdir}/ADM_plugins6/autoScripts/PSP.py
%{_libdir}/ADM_plugins6/autoScripts/svcd.py
%{_libdir}/ADM_plugins6/autoScripts/vcd.py
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_asf.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_avsproxy.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_flv.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_matroska.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_mp4.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_mxf.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_opendml.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_pic.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_ps.so
%{_libdir}/ADM_plugins6/demuxers/libADM_dm_ts.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_avi.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_dummy.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_ffPS.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_ffTS.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_flv.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_Mkv.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_mp4.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_mp4v2.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_raw.so
%{_libdir}/ADM_plugins6/muxers/libADM_mx_Webm.so
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/ultraFast.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/PSP.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/veryFast.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/fast.json
%{_libdir}/ADM_plugins6/pluginSettings/x264/3/iPhone.json
%{_libdir}/ADM_plugins6/scriptEngines/libADM_script_tinyPy.so
%{_libdir}/ADM_plugins6/videoDecoders/libADM_vd_vpx.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffDv.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffFlv1.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffMpeg2.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_ffMpeg4.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_huff.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_jpeg.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_null.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_png.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_xvid4.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_yv12.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_ascii.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_avsfilter.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_addBorders.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_black.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_changeFps.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_colorYuv.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_denoise3d.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_denoise3dhq.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_DgBob.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_dummy.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_fadeTo.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_fadeToBlack.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_FluxSmooth.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_gauss.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_hflip.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_hzstackField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_ivtcDupeRemover.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_kernelDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_largeMedian.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_lavDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_lumaOnly.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_mean.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_median.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_mergeField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_printInfo.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_removePlane.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_resampleFps.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_rotate.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_ssa.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_separateField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_sharpen.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_stackField.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_swapUV.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_telecide.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_unstackField.so
%if %{with build_qt5}
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vaapiFilter.so
%endif
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vdpauFilter.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vdpauFilterDeint.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_vflip.so
%{_libdir}/ADM_plugins6/videoFilters/libADM_vf_yadif.so
%dir %{_datadir}/ADM6_addons
%dir %{_datadir}/ADM6_addons/avsfilter
%{_datadir}/ADM6_addons/avsfilter/avsload.exe
%{_datadir}/ADM6_addons/avsfilter/pipe_source.dll
%{_mandir}/man1/avidemux.1.gz
%doc AUTHORS COPYING README

%files cli
%defattr(-,root,root)
%{_bindir}/avidemux3_cli
%{_libdir}/libADM_render6_cli.so
%{_libdir}/libADM_UI_Cli6.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_x264_cli.so
%{_libdir}/ADM_plugins6/videoEncoders/libADM_ve_x265_cli.so
%dir %{_libdir}/ADM_plugins6/videoFilters/cli
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_blackenBordersCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_chromaShiftCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_contrastCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_CropCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_eq2Cli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_HueCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_logoCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_mpdelogoCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_msharpenCli.so
%{_libdir}/ADM_plugins6/videoFilters/cli/libADM_vf_swscaleResize_cli.so

%files qt%{qtversion}
%defattr(-,root,root)
%{_bindir}/avidemux3_jobs_qt%{qtversion}
%{_bindir}/avidemux3_qt%{qtversion}
%if %{with with_vs}
%{_bindir}/vsProxy_gui_qt%{qtversion}
%endif
%{_libdir}/libADM_openGLQT%{qtversion}6.so
%{_libdir}/libADM_render6_QT%{qtversion}.so
%{_libdir}/libADM_UIQT%{qtversion}6.so
%dir %{_libdir}/ADM_plugins6/shaderDemo
%dir %{_libdir}/ADM_plugins6/shaderDemo/1
%dir %{_libdir}/ADM_plugins6/videoEncoders/qt%{qtversion}
%dir %{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}
%{_libdir}/ADM_plugins6/shaderDemo/1/bump.shader
%{_libdir}/ADM_plugins6/shaderDemo/1/lightning.shader
%{_libdir}/ADM_plugins6/shaderDemo/1/ripple.shader
%{_libdir}/ADM_plugins6/shaderDemo/1/zigzag.shader
%{_libdir}/ADM_plugins6/videoEncoders/qt%{qtversion}/libADM_ve_x264_QT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoEncoders/qt%{qtversion}/libADM_ve_x265_QT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_asharpQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_blackenBordersQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_chromaShiftQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_contrastQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_cropQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_eq2QT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_glBenchmark.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_glResize.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_HueQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_logoQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_mpdelogoQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_msharpenQT%{qtversion}.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_rotateGlFrag2.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_sampleGlFrag2.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_sampleGlVertex.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_shaderLoaderGl.so
%{_libdir}/ADM_plugins6/videoFilters/qt%{qtversion}/libADM_vf_swscaleResizeQT%{qtversion}.so
%{_datadir}/applications/avidemux3-qt%{qtversion}.desktop
%if %{with with_vs}
%{_datadir}/applications/vsproxy-qt%{qtversion}.desktop
%endif
%{_datadir}/pixmaps/avidemux3.png

%files qt%{qtversion}-lang
%defattr(-,root,root)
%dir %{_datadir}/avidemux3
%dir %{_datadir}/avidemux3/qt%{qtversion}
%dir %{_datadir}/avidemux3/qt%{qtversion}/i18n
%{_datadir}/avidemux3/qt%{qtversion}/i18n/*.qm

%changelog
* Sun Apr 30 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.20
  + Audio : AAC in mpegTS fix
  + Audio : external AAC import fix
  + MKV : try to better guess original timestamp
  + i18n : Russian and German translation update
    (TotalCaesar659 / euma)
  + UI : Filter UI fix
* Thu Mar 30 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.19
  + Filter : All filters with preview have better navigation
    dialogs
  + Filter : Delogo filter UI redone
  + Filter : Fixed changeFps/resampleFps seeking
  + TS/Demux : HEVC support improved
  + Flv/Demux : Support large files (rcdrone)
  + Audio : Allow EAC3 as external audio track
  + UI : General usability cleanup (euma)
  + UI : Allow using the last read folder as default save folder
    (euma)
  + UI : 2 pass encoding dialog cleanup (euma)
  + UI : Dynamically enable/disable menu (euma)
  + UI : Customizable keyboard shortcut (euma)
  + UI : Allow reverting page up/down (euma)
  + Codec : Better support for 10bits
  + i18n : Russian translation updated (TotalCaesar659)
  + i18n : Greek translation updated (nikoss)
  + i18n : General cleanup (euma)
  + Updated ffmpeg libs to 3.0.7
* Sun Jan  8 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.18
  * Fixed slider in preview mode
- Version 2.6.17
  * Allow EAC3 in mp4 and mp4v2 (fiftyplus/euma)
  * Fix behaviour of preview window when video size is ~ screen
    size
* Fri Jan  6 2017 joerg.lorenzen@ki.tng.de
- Enabled support for fdk-aac.
* Wed Jan  4 2017 joerg.lorenzen@ki.tng.de
- Update to version 2.6.16
  + Build : Avidemux can be built with visual c++ 2015 (losing
    some ASM)
  + OsX : Initialize fontconfig so that subtitling works
  + Core : Update ffmpeg to 3.0.5
  + i18n : Updated fr and ru translations
    (jean Elchinger/totalcaesar659)
  + Build : Improved build scripts (euma)
  + x265 : Enforce complicancy with most devices
  + vaapi : Add resizer
  + UI : Redone UI, revamped contrast filter
  + Qt : Dont use too much CPU on playback when there is no audio
    track
  + Qt : Reenabled nvenc + Fixed keyframe detection
  + Qt : Fixed a crash when encoding starts very slowly (x265)
  + Build : Allow use of system libass, liba52,libmad (euma)
* Mon Nov 21 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.15
  + Hw Accel : Fixed nvEnc and added simple nvEnc-HEVC
    (windows/linux)
  + Hw Accel : Added support for HEVC/VC1 with libVA (linux)
  + Hw Accel : Experimental Dxva2 video decoder + Dxva2/D3D display
    engine (windows)
  + Demux : Mpeg TS, fix non multiple of 16 file management (euma)
  + Audio/win32 : Fixed CPU consumption when playing audio
  + Editor : Fixed copy /paste /delete /undo (euma)
  + Editor : A *lot* of seeking bugs fixed (euma)
  + Editor : A *lot* of marker management bugs fixed (euma)
  + Audio : Added FDK-AAC as encoder
  + x26* : Added a "None" preset
  + x265 : Fixed 2 pass encoding on windows
  + i18n : Qt4 vs Qt5 language fix (D. Amm)
  + i18n : German translation updated (euma)
  + UI : Added reload default settings (euma)
  + UI : Allow minimizing to tray while encoding (euma)
  + OSX : Update to Sierra
* Wed Sep 21 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.14
  i18n:
  + A lot more is now translatable (D. Amm)
  + Hungarian translation (rezso)
  + German translation update (euma)
  + French translation update
  + PT/BR translation partially fixed
  + Dannish translation update (scootergrisen)
  Platforms:
  + Qtx : Automatically check if a new version is available once a
    day
  + WIN32 : Reverted to MXE cross compiler, XP now works again
  + OSX : Fixed the packager, it should work every time now (no
    more borked dmg)
  Application:
  + Decoding : Deal with corrupted stream in a nicer way (H264/TS)
  + Decoding : Enable lagarith
  + Decoding : Support for flac through libavcodec
  + VDPAU : Try harder to release resources at exit
  + Demuxer : Image loader improved and cleaned up, more jpeg
    formats are supported
  + Editor : Try to deal better with corrupted audio in copy mode
  + TS : Add support for new EAC3 identifier such as the ones used
    by numericable / DVB-T
  + Encoder : Fix most of the libavcodec based encoders
* Sat Aug 20 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.13
  + [OsX] Toolchain updated
  + [Win64] Toolchain updated
  + [Linux] AppImage (universal linux64 binaries)
  + [Core] Update to libav* 3.0.2
  + [Edit] Improved copy mode for h264/h265 video
  + [Audio] AAC/ADTS import/export
  + [Filter] new video filter : ivtcDupeRemover to remove duplicate
    after 3:2 pulldown
  + [Qt] Revamped refresh screen
  + [Filters] ASS/SSA fixes
  + [Filters] Improved logo filter with alpha channel
  + [Win32] Development files included in installer
  + [Filter] ShaderLoader, load your openGL shaders as filters
  + [Linux] Compatibility with newer gcc
  + [Filter] Partial filter available only for one in/one out video
    filters
  + [UI] Add go fwd/go backward 60 sec buttons
  + [i18n] Translations updated
- Removed avidemux-find-lrelease-qt5.patch, fixed upstream
- Fixed all patches
- Disabled ix86 for SLES 11 because build currently fails
  (perhaps compiler too old?)
* Tue Mar  8 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.12
  + [H264] Fixed crash when saving h264 annexB in avi (Brundle)
  + [Vdpau] Fixed VDPAU resize and deinterlace when height is padded
  + [Mkv] Faster loading of VP9 and h265
  + [MP4] Supports more flavors of H265
  + [i18n] Spanish translation update by ringmaster
  + [Edit] Another frame seeking bug fixed, happened rarely
  + [All] Slightly better crash handler
  + [FFmpeg]Update to 2.7.6
  + [Muxer] Basic webm support
  + [Jobs] Fixed right click menus with qt5
* Fri Feb  5 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.6.11
  + Better support for H265
  + Fix off-by-one keyframe cutting
  + Basic support for Opus
  + Try to cope better with decoding error
  + Extract keyframes from non Mpeg video in mkv
  + Cap refresh rate for large video or slow machines
  + Fix nv12 to yv12 mmx code
- Update internal ffmpeg to version 2.8.6
- Build against qt5 for openSUSE > 13.2 and Leap 42.1
- Don't build gtk frontend because build currently fails and it
  hasn't been maintained for a long time (information from
  developer)
* Mon Jan 18 2016 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.5
* Wed Dec 23 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.4
* Sat Dec  5 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.3
* Fri Nov 20 2015 olaf@aepfle.de
- Set group permissions for included ffmpeg libs
* Fri Oct 16 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8.1
* Wed Sep  9 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.8
* Mon Jul 20 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 2.7.2
* Sat Jul 11 2015 joerg.lorenzen@ki.tng.de
- Update to version 2.6.10
  * Re-added translations
  * Re-added avsproxy
  * Fixed multi passes with x264 when file has non ascii chars
  * Added experimental Qt5 build for mac
  * Fixed a bug with filler frames (fraps)
- update internal ffmpeg to version 2.7.1
- Version 2.6.9
  * x265 support by KoolAidMan.
  * Qt4 and Qt5 support.
  * Compatibility with newer VAAPI.
  * Updated ffmpeg libraries.
  * Simple support for nvenc (linux).
  * Better compatibility with Dash file, Flv.
  * AvsProxy improvements (hinterwaeldler).
  * Misc fixes (asjchult).
  * Plenty of bugfixes and new bugs.
  * Win32 and Win64 builds are now using winbuilds.org, Xp no
    longer supported.
* Sat May  2 2015 joerg.lorenzen@ki.tng.de
- fixed build for openSUSE = 11.4
* Thu Feb 26 2015 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.12
* Tue Dec 23 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.11
- removed workaround for build on arm armv6l/armv6hl, the problem
  is caused by additional RaspberryPi repository and should be
  fixed there
* Sat Dec 13 2014 joerg.lorenzen@ki.tng.de
- removed some unneeded dependencies to enable build on armv6l/armv6hl
* Sat Nov  8 2014 joerg.lorenzen@ki.tng.de
- added patch and dependencies to enable build on ARM CPU
- removed some unneeded dependencies
* Wed Nov  5 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.10
* Fri Oct 17 2014 joerg.lorenzen@ki.tng.de
- changed BuildRequires to pkgconfig where possible
- enable build for SLES, unfortunately without frontends qt and gtk
  because SLES doesn't provide gtk3 and qt >= 4.7
* Fri Oct 10 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.9
* Fri Aug 22 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.8
* Tue Jun 24 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.7
* Fri Mar 14 2014 joerg.lorenzen@ki.tng.de
- Update to version 2.6.8
  * Image/export: Proper initialization of Qz for jpeg export
  * UI : Add an override menu to force language
  * tinypy : Add support for os.environ
  * x264 : Improved settings (tobias)
  * Win32 : Fix crash when having an audio problem
  * Win32 : Re-add mp4v2 to installer files
  * Audio/FAAC : Fix channel mapping when source is mono
  * Audio/AMR : Re-enabled AMR
  * Audio/lavc : Fixed encoding for codec not supporting planar (MP2)
  * Audio : Fixed importing MP2 audio detected as MP3
  * Editor : Fix deleting chunks of the video leading to seek errors
  * Editor : Initial copy/paste support
  * Editor/audio: Fix issue when source has more than 4 tracks
  * Editor : Better detection of double fps input files
  * TS/Demux : Brute force eac3 probe
  * TS/Demux : Better initialization, avoid dropping audio
  * MP4/Demux : Fix management of PCM audio
  * Mkv/Demux : Proper re-indexing for mpeg2 in mkv
  * Mp4v2/Mux : Add fast start mode back
  * OpenSolaris : Some fixes by pfelecan
  * Subtitles : Update libass + very simple srt2ssa converter
  * OsX : Enables more optional codecs...
  * avsfilte : Performance Improvements (fahr)
* Wed Mar 12 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.6
* Sat Feb  1 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 1.2.5
* Mon Dec  9 2013 joerg.lorenzen@ki.tng.de
- Update to version 2.6.7
  * [MKV] Fix seeking in h264
  * [TS/H264] Split on NALU boundaries, it was off by one byte
  * [TS/AAC] Add support for AAC/LC/SBR
  * [MOV/MP4] Correct management of PCM/8Bits audio track
  * [Images] Fixed import of bmp and jpg
  * [Build] Support for newer cmake (ajschult)
  * [Build] Better RPM generation (mit)
  * [Auto/PSP] Fixed scripts (LJ)
* Sat Nov  2 2013 joerg.lorenzen@ki.tng.de
- changes in spec file to enable build for openSUSE 11.4 and 12.1
* Wed Oct 30 2013 joerg.lorenzen@ki.tng.de
- Initial package, version 2.6.6
